Index: third_party/freetype/src/base/ftfntfmt.c |
diff --git a/third_party/freetype/src/base/ftxf86.c b/third_party/freetype/src/base/ftfntfmt.c |
similarity index 67% |
rename from third_party/freetype/src/base/ftxf86.c |
rename to third_party/freetype/src/base/ftfntfmt.c |
index a4bf767dfa25242f4806d6b6863379c847e003ac..98e7431a2b94648b13ddb5edb9e92c97a326b669 100644 |
--- a/third_party/freetype/src/base/ftxf86.c |
+++ b/third_party/freetype/src/base/ftfntfmt.c |
@@ -1,10 +1,10 @@ |
/***************************************************************************/ |
/* */ |
-/* ftxf86.c */ |
+/* ftfntfmt.c */ |
/* */ |
/* FreeType utility file for X11 support (body). */ |
/* */ |
-/* Copyright 2002, 2003, 2004 by */ |
+/* Copyright 2002-2015 by */ |
/* David Turner, Robert Wilhelm, and Werner Lemberg. */ |
/* */ |
/* This file is part of the FreeType project, and may only be used, */ |
@@ -17,12 +17,27 @@ |
#include <ft2build.h> |
-#include FT_XFREE86_H |
+#include FT_FONT_FORMATS_H |
#include FT_INTERNAL_OBJECTS_H |
-#include FT_SERVICE_XFREE86_NAME_H |
+#include FT_SERVICE_FONT_FORMAT_H |
- /* documentation is in ftxf86.h */ |
+ /* documentation is in ftfntfmt.h */ |
+ |
+ FT_EXPORT_DEF( const char* ) |
+ FT_Get_Font_Format( FT_Face face ) |
+ { |
+ const char* result = NULL; |
+ |
+ |
+ if ( face ) |
+ FT_FACE_FIND_SERVICE( face, result, FONT_FORMAT ); |
+ |
+ return result; |
+ } |
+ |
+ |
+ /* deprecated function name; retained for ABI compatibility */ |
FT_EXPORT_DEF( const char* ) |
FT_Get_X11_Font_Format( FT_Face face ) |
@@ -31,7 +46,7 @@ |
if ( face ) |
- FT_FACE_FIND_SERVICE( face, result, XF86_NAME ); |
+ FT_FACE_FIND_SERVICE( face, result, FONT_FORMAT ); |
return result; |
} |
@@ -1,10 +1,10 @@ |
/* */ |
-/* FreeType utility file for X11 support (body). */ |
+/* FreeType utility file for font formats (body). */ |
/* */ |